@@ -14,13 +14,15 @@ BoS ɸץ饰
 *bos_plugin.rb
 *bos_user.rb
 *bos_prop.rb
-*wiki.class
+*bos_miniwiki.rb
+*bos_category.rb
 
 ==plugin
 *bos_pg.rb
 *bos_plugin.rb
 *bos_user.rb
 *bos_prop.rb
+*bos_miniwiki.rb
 
 ==template
 *product.htm
@@ -33,4 +35,7 @@ BoS ɸץ饰
 *user.htm
 *prop.htm
 
+==admin_plugin
+*bos_admin.rb
+
 =end
