@@ -1,4 +1,4 @@
-# $Id: bos_miniwiki.rb,v 1.8 2005/06/03 00:56:06 nisi Exp $
+# $Id: bos_miniwiki.rb,v 1.9 2005/06/16 21:52:30 nisi Exp $
 
 require "cgi"
 
@@ -95,6 +95,8 @@ class WikiParser
 			when /^(\!{1,6})(.+)/
 				rest.call(false,[])
 				ret << {:tag => "h#{$1.size}".intern, :contents => inline_parse($2)}
+			when /^(\/\/)/
+				rest.call(false,[])
 			when /^(\s|\:|\"\"|\|\||[\*\#]+)(.*)/
 				tcom = false
 				ea,ed = $1,$2
@@ -129,7 +131,7 @@ class WikiParser
 					trec = []
 					ed.split('||').each do |r|
 						r =~ /^(\~?)([\^\>]*)/
-						rws,cls = $2.count('^'),$2.count('>')
+						rws,cls = $2.count('^')+1,$2.count('>')+1
 						thas = {
 							:tag => $1 == "~" ? :th : :td ,
 							:contents => inline_parse($') }
