@@ -1,24 +1,26 @@
-# $Id: bos_pg.rb,v 1.7 2005/05/18 00:04:30 nisi Exp $
+# $Id: bos_pg.rb,v 1.11 2005/06/18 01:56:29 nisi Exp $
 
 class BosPagegen
 	include BOS::PropMethods
 	
-	Table_name = "bos_#{Prop[:site_name]}_products"
+	Table_name = "bos_#{BOS::Prop[:site_name]}_products"
 	Pages = {}
-	BOS::Rdb.exp({
-		:command => "s",
-		:target  => Table_name,
-		:cols    => {
-			:product_id      => 0,
-			:product_name    => "- no name -"}}).each do |v|
-		Pages.store(v[:product_id],v[:product_name])
+	if BOS::MySQLo.list_tables.include?(Table_name) then
+		BOS::Rdb.exp({
+			:command => "s",
+			:target  => Table_name,
+			:cols    => {
+				:product_id      => 0,
+				:product_name    => "- no name -"}}).each do |v|
+					Pages.store(v[:product_id],v[:product_name])
+				end
 	end
 	
 	def initialize(product_id)
 		@mydb = BOS::MySQLo
-		@mydo = BOS::Rdb
+		@mydo = Rudby.new(BOS::MySQLo)
 		@prop = set_default
-		setup if Prop[:sitesetup] && !@mydb.list_tables.include?(Table_name)
+		setup if BOS::Prop[:sitesetup] && !@mydb.list_tables.include?(Table_name)
 		if !(product_id.is_a? Numeric) || !(product_id.integer?) then
 			product_id = product_id.to_i == 0 ? get_id(product_id) : product_id.to_i
 		end
@@ -32,22 +34,16 @@ class BosPagegen
 			"product_id INT NOT NULL AUTO_INCREMENT PRIMARY KEY," +
 			"product_name VARCHAR(255)," +
 			"content TEXT," +
+			"user_id VARCHAR(20)," +
+			"group_id INT," +
+			"permission INT," +
 			"template VARCHAR(64)," +
 			"disp_start_date DATETIME," +
-			"disp_end_date DATETIME," +
-			"disp_flg CHAR(1) );")
+			"disp_end_date DATETIME );")
 	end
 	
 	def get_id(titlestr=nil)
 		return 0 if !titlestr
-#		ret = 0
-#		retr = @mydo.exp({
-#			:command => "s",
-#			:target  => Table_name,
-#			:cols    => {:product_id => 0},
-#			:where   => w("product_name"){|a| a == titlestr } })
-#		ret = retr[0][:product_id] if retr && retr[0]
-#		ret
 		Pages.index(titlestr)
 	end
 	
@@ -94,11 +90,53 @@ class BosPagegen
 			:product_name    => "- no name -",
 			:content         => "",
 			:template        => "",
+			:user_id         => "",
+			:group_id        => "",
+			:permission      => 0750,
 			:disp_start_date => DateTime.now,
-			:disp_end_date   => DateTime.now,
-			:disp_flg        => "n" }
+			:disp_end_date   => DateTime.parse("9999/01/01") }
 	end
 	
+	def chk_permission(b)
+		r,w,x = false,false,false
+		if defined?(b.groups) && b.groups.include?(1) then
+			r,w,x = true,true,true
+		else
+			if chk_user(b) then
+				r = (@prop[:permission][8] == 1)
+				w = (@prop[:permission][7] == 1)
+				x = (@prop[:permission][6] == 1)
+			elsif chk_group(b) then
+				r = (@prop[:permission][5] == 1)
+				w = (@prop[:permission][4] == 1)
+				x = (@prop[:permission][3] == 1)
+			else
+				r = (@prop[:permission][2] == 1)
+				w = (@prop[:permission][1] == 1)
+				x = (@prop[:permission][0] == 1)
+			end
+		end
+		return  r,w,x
+	end
+	
+	def chk_group(b)
+		if defined?(b.groups) then
+			b.groups.include?(@prop[:group_id])
+		else
+			if b then
+				b.include?(@prop[:group_id])
+			else
+				false
+			end
+		end
+	end
+	
+	def chk_user(b)
+		return false unless defined?(b[])
+		b[:user_id] == @prop[:user_id]
+	end
+#	alias :=~ :chk_group
+	
 	def commit
 		if @prop[:product_id] == 0 then
 			@prop.delete(:product_id)
