@@ -1,16 +1,23 @@
-# $Id: bos_plugin.rb,v 1.7 2005/04/15 23:02:43 nisi Exp $
+# $Id: bos_plugin.rb,v 1.9 2005/06/18 01:56:29 nisi Exp $
 
 class BosPlugin
 
 	def initialize
 		@mydb = BOS::MySQLo
-		@mydo = BOS::Rdb
+		@mydo = Rudby.new(BOS::MySQLo)
 		@exdir = "extensions"
+		@exsite = ""
 		@plist = {
 			'class'          => "./" + BOS::Prop[:class_dir],
 			'plugin'         => "./" + BOS::Prop[:plugin_dir],
 			'template'       => "./",
-			'admin_template' => "./" + BOS::Prop[:admin_dir] }
+			'admin_template' => "./" + BOS::Prop[:admin_dir],
+			'admin_class'    => "./" + BOS::Prop[:admin_dir] + "/" + BOS::Prop[:class_dir],
+			'admin_plugin'   => "./" + BOS::Prop[:admin_dir] + "/" + BOS::Prop[:plugin_dir] }
+	end
+	
+	def exsite=(siteurl)
+		@exsite = siteurl
 	end
 	
 	def get_plugin_list
